@@ -41,7 +41,8 @@ static QString etagFromHeaders(const QString &headers)
 }
 
 DavItemFetchJob::DavItemFetchJob(const DavItem &item, QObject *parent)
-    : DavJobBase(parent), mItem(item)
+    : DavJobBase(parent)
+    , mItem(item)
 {
 }
 
@@ -67,9 +68,11 @@ DavItem DavItemFetchJob::item() const
 void DavItemFetchJob::davJobFinished(KJob *job)
 {
     KIO::StoredTransferJob *storedJob = qobject_cast<KIO::StoredTransferJob *>(job);
-    const int responseCode = storedJob->queryMetaData(QStringLiteral("responsecode")).isEmpty() ?
-                             0 :
-                             storedJob->queryMetaData(QStringLiteral("responsecode")).toInt();
+    const QString responseCodeStr = storedJob->queryMetaData(QStringLiteral("responsecode"));
+    const int responseCode = responseCodeStr.isEmpty()
+                             ? 0
+                             : responseCodeStr.toInt();
+
     setLatestResponseCode(responseCode);
 
     if (storedJob->error()) {
@@ -86,4 +89,3 @@ void DavItemFetchJob::davJobFinished(KJob *job)
 
     emitResult();
 }
-
